@@ -2,14 +2,14 @@
  *
  *  Name:       dataset.c
  *
- *  Version:    2.9-2
+ *  Version:    2.11-1
  *
  *  Purpose:    NetCDF dataset functions for RNetCDF
  *
  *  Author:     Pavel Michna (rnetcdf-devel@bluewin.ch)
  *              Milton Woods (miltonjwoods@gmail.com)
  *
- *  Copyright (C) 2004-2024 Pavel Michna and Milton Woods.
+ *  Copyright (C) 2004-2025 Pavel Michna and Milton Woods.
  *
  *=============================================================================*
  *
@@ -30,6 +30,7 @@
  *=============================================================================*
  */
 
+#include "config.h"
 
 #include <stdio.h>
 #include <string.h>
@@ -177,6 +178,9 @@ R_nc_create (SEXP filename, SEXP clobber, SEXP share, SEXP prefill,
 #endif
   }
 
+  /*-- Close any stale netcdf handles that could point to this file -----------*/
+  R_gc();
+
   /*-- Create the file --------------------------------------------------------*/
   filep = R_nc_strarg (filename);
   if (strlen (filep) > 0) {
@@ -298,6 +302,9 @@ R_nc_open (SEXP filename, SEXP write, SEXP share, SEXP prefill,
     fillmode = NC_NOFILL;
   }
 
+  /*-- Close any stale netcdf handles that could point to this file -----------*/
+  R_gc();
+
   /*-- Open the file ----------------------------------------------------------*/
   filep = R_nc_strarg (filename);
   if (strlen (filep) > 0) {
